# eric7.Preferences.ConfigurationPages.WebBrowserSpellCheckingPage

Module implementing the Web Browser Spell Checking configuration page.

### Global Attributes

None

### Classes

WebBrowserSpellCheckingPage | Class implementing the Web Browser Spell Checking page.

### Functions

create | Module function to create the configuration page.

## WebBrowserSpellCheckingPage

Class implementing the Web Browser Spell Checking page.

### Derived from

ConfigurationPageBase, Ui_WebBrowserSpellCheckingPage

### Class Attributes

None

### Class Methods

None

### Methods

WebBrowserSpellCheckingPage | Constructor
__createLanguageString | Private method to create a language string given a language identifier.
__populateDictionariesList | Private method to populate the spell checking dictionaries list.
on_manageDictionariesButton_clicked | Private slot to manage spell checking dictionaries.
on_spellCheckEnabledCheckBox_clicked | Private slot handling a change of the spell checking enabled state.
save | Public slot to save the Help Viewers configuration.

### Static Methods

None

#### WebBrowserSpellCheckingPage (Constructor)

WebBrowserSpellCheckingPage()

Constructor

#### WebBrowserSpellCheckingPage.__createLanguageString

__createLanguageString(language)

Private method to create a language string given a language identifier.

language (str)
  language identifier

Return:
  language string

Return Type:
  str

#### WebBrowserSpellCheckingPage.__populateDictionariesList

__populateDictionariesList()

Private method to populate the spell checking dictionaries list.

#### WebBrowserSpellCheckingPage.on_manageDictionariesButton_clicked

on_manageDictionariesButton_clicked()

Private slot to manage spell checking dictionaries.

#### WebBrowserSpellCheckingPage.on_spellCheckEnabledCheckBox_clicked

on_spellCheckEnabledCheckBox_clicked()

Private slot handling a change of the spell checking enabled state.

#### WebBrowserSpellCheckingPage.save

save()

Public slot to save the Help Viewers configuration.

Up

## create

create(dlg)

Module function to create the configuration page.

dlg (Configuration)
  reference to the configuration dialog

Return:
  reference to the instantiated page

Return Type:
  ConfigurationPageBase

Up